#[repr(u32)]pub enum AutotuneAxis {
AUTOTUNE_AXIS_ROLL = 1,
AUTOTUNE_AXIS_PITCH = 2,
AUTOTUNE_AXIS_YAW = 4,
}Available on crate feature
dialect-marsh only.Expand description
Axes that will be autotuned by MAV_CMD_DO_AUTOTUNE_ENABLE. Note that at least one flag must be set in MAV_CMD_DO_AUTOTUNE_ENABLE.param2: if none are set, the flight stack will tune its default set of axes.
Variants
AUTOTUNE_AXIS_ROLL = 1
Autotune roll axis.
AUTOTUNE_AXIS_PITCH = 2
Autotune pitch axis.
AUTOTUNE_AXIS_YAW = 4
Autotune yaw axis.
Implementations
Sourceimpl AutotuneAxis
impl AutotuneAxis