#[repr(u32)]pub enum MarshModeFlags {
MARSH_MODE_SINGLE_MESSAGE = 16_777_216,
MARSH_MODE_ALL_MESSAGES = 33_554_432,
}Available on crate feature
dialect-marsh only.Expand description
These values are MARSH-specific modes intended to be sent in custom_mode field of HEARTBEAT message. Prefer defining values in the most significant byte (between 2^24 and 2^31) to leave the lower three bytes to contain a message id
Variants
MARSH_MODE_SINGLE_MESSAGE = 16_777_216
Request Manager to only send one specific message, advised for very resource limited nodes or with control flow limitations like Simulink. That message id should be in the lower three bytes of the mode, which can be done by adding it to the flags.
MARSH_MODE_ALL_MESSAGES = 33_554_432
Request Manager to send every message going out to any of the clients.
Implementations