#[repr(u32)]pub enum MarshType {
MARSH_TYPE_MANAGER = 100,
MARSH_TYPE_FLIGHT_MODEL = 101,
MARSH_TYPE_CONTROLS = 102,
MARSH_TYPE_VISUALISATION = 103,
MARSH_TYPE_INSTRUMENTS = 104,
MARSH_TYPE_MOTION_PLATFORM = 105,
MARSH_TYPE_GSEAT = 106,
MARSH_TYPE_EYE_TRACKER = 107,
MARSH_TYPE_CONTROL_LOADING = 108,
MARSH_TYPE_VIBRATION_SOURCE = 109,
MARSH_TYPE_PILOT_TARGET = 110,
MARSH_TYPE_EXPERIMENT_DIRECTOR = 111,
}dialect-marsh only.Expand description
Component types for different nodes of the simulator network (flight model, controls, visualisation etc.). Components will always receive messages from the Manager relevant for their type. Only the first component in a network with a given system ID and type will have its messages forwarded by the Manager, all other ones will only be treated as output (will be shadowed). This enum is an extension of MAV_TYPE documented at https://mavlink.io/en/messages/minimal.html#MAV_TYPE
Variants
MARSH_TYPE_MANAGER = 100
The simulation manager responsible for routing packets between different nodes. Typically MARSH Manager, see https://marsh-sim.github.io/manager.html
MARSH_TYPE_FLIGHT_MODEL = 101
Component simulating flight dynamics of the aircraft.
MARSH_TYPE_CONTROLS = 102
Component providing pilot control inputs.
MARSH_TYPE_VISUALISATION = 103
Component showing the visual situation to the pilot.
MARSH_TYPE_INSTRUMENTS = 104
Component implementing pilot instrument panel.
MARSH_TYPE_MOTION_PLATFORM = 105
Component that moves the entire cockpit for motion cueing.
MARSH_TYPE_GSEAT = 106
Component for in-seat motion cueing.
MARSH_TYPE_EYE_TRACKER = 107
Component providing gaze data of pilot eyes.
MARSH_TYPE_CONTROL_LOADING = 108
Component measuring and actuating forces on pilot control inputs.
MARSH_TYPE_VIBRATION_SOURCE = 109
Component providing vibrations for system identification, road rumble, gusts, etc.
MARSH_TYPE_PILOT_TARGET = 110
Component providing target for the pilot to follow like controls positions, aircraft state, ILS path etc.
MARSH_TYPE_EXPERIMENT_DIRECTOR = 111
Principal component controlling the main scenario of a given test, (unlike lower level MARSH_TYPE_PILOT_TARGET or MARSH_TYPE_MANAGER for overall communication).
Implementations