#[repr(u32)]pub enum MotionPlatformHealth {
MOTION_PLATFORM_HEALTH_OK = 0,
MOTION_PLATFORM_HEALTH_WARNING = 1,
MOTION_PLATFORM_HEALTH_ERROR = 2,
MOTION_PLATFORM_HEALTH_CRITICAL = 3,
}Available on crate feature
dialect-marsh only.Expand description
General error state of a motion platform system.
Variants
MOTION_PLATFORM_HEALTH_OK = 0
System is operating correctly.
MOTION_PLATFORM_HEALTH_WARNING = 1
There is at least one warning present, but operation can be continued.
MOTION_PLATFORM_HEALTH_ERROR = 2
There is a failure or misconfiguration that requires operator’s attention for correct operation.
MOTION_PLATFORM_HEALTH_CRITICAL = 3
There is a major failure that requires immediate operator action to maintain safety.
Implementations