#[repr(u32)]pub enum MotionPlatformMode {
MOTION_PLATFORM_MODE_UNKNOWN = 0,
MOTION_PLATFORM_MODE_UNINITIALIZED = 1,
MOTION_PLATFORM_MODE_OFF = 2,
MOTION_PLATFORM_MODE_SETTLED = 3,
MOTION_PLATFORM_MODE_NEUTRAL = 4,
MOTION_PLATFORM_MODE_FROZEN = 5,
MOTION_PLATFORM_MODE_ENGAGED = 6,
}Available on crate feature
dialect-marsh only.Expand description
Mode of a motion platform system.
Variants
MOTION_PLATFORM_MODE_UNKNOWN = 0
Mode information is unsupported on this device.
MOTION_PLATFORM_MODE_UNINITIALIZED = 1
Mode is currently not available, but may be in different condition.
MOTION_PLATFORM_MODE_OFF = 2
Platform actuators are turned off, but control system is responsive.
MOTION_PLATFORM_MODE_SETTLED = 3
Platform is in the lowest position and/or locked, appropriate for personnel entry.
MOTION_PLATFORM_MODE_NEUTRAL = 4
Platform is in a neutral reference position, not accepting movement commands.
MOTION_PLATFORM_MODE_FROZEN = 5
Platform is stopped in any position, not accepting movement commands.
MOTION_PLATFORM_MODE_ENGAGED = 6
Platform is in any position, accepting movement commands.
Implementations