pub struct AVAILABLE_MODES_MONITOR_DATA {
pub seq: u8,
}Available on crate feature
dialect-marsh only.Expand description
A change to the sequence number indicates that the set of AVAILABLE_MODES has changed. A receiver must re-request all available modes whenever the sequence number changes. This is only emitted after the first change and should then be broadcast at low rate (nominally 0.3 Hz) and on change. See https://mavlink.io/en/services/standard_modes.html.
ID: 437
Fields
seq: u8Sequence number. The value iterates sequentially whenever AVAILABLE_MODES changes (e.g. support for a new mode is added/removed dynamically).
Implementations