pub struct COMPONENT_INFORMATION_DATA {
pub time_boot_ms: u32,
pub general_metadata_file_crc: u32,
pub peripherals_metadata_file_crc: u32,
pub general_metadata_uri: CharArray<100>,
pub peripherals_metadata_uri: CharArray<100>,
}COMPONENT_METADATA (Deprecated since 2022-04)dialect-marsh only.Expand description
Component information message, which may be requested using MAV_CMD_REQUEST_MESSAGE.
ID: 395
Fields
time_boot_ms: u32COMPONENT_METADATA (Deprecated since 2022-04)Timestamp (time since system boot).
general_metadata_file_crc: u32COMPONENT_METADATA (Deprecated since 2022-04)CRC32 of the general metadata file (general_metadata_uri).
peripherals_metadata_file_crc: u32COMPONENT_METADATA (Deprecated since 2022-04)CRC32 of peripherals metadata file (peripherals_metadata_uri).
general_metadata_uri: CharArray<100>COMPONENT_METADATA (Deprecated since 2022-04)MAVLink FTP URI for the general metadata file (COMP_METADATA_TYPE_GENERAL), which may be compressed with xz. The file contains general component metadata, and may contain URI links for additional metadata (see COMP_METADATA_TYPE). The information is static from boot, and may be generated at compile time. The string needs to be zero terminated.
peripherals_metadata_uri: CharArray<100>COMPONENT_METADATA (Deprecated since 2022-04)(Optional) MAVLink FTP URI for the peripherals metadata file (COMP_METADATA_TYPE_PERIPHERALS), which may be compressed with xz. This contains data about โattached componentsโ such as UAVCAN nodes. The peripherals are in a separate file because the information must be generated dynamically at runtime. The string needs to be zero terminated.
Implementations