pub struct DISTANCE_SENSOR_DATA {
pub time_boot_ms: u32,
pub min_distance: u16,
pub max_distance: u16,
pub current_distance: u16,
pub mavtype: MavDistanceSensor,
pub id: u8,
pub orientation: MavSensorOrientation,
pub covariance: u8,
pub horizontal_fov: f32,
pub vertical_fov: f32,
pub quaternion: [f32; 4],
pub signal_quality: u8,
}dialect-marsh only.Expand description
Distance sensor information for an onboard rangefinder.
ID: 132
Fields
time_boot_ms: u32Timestamp (time since system boot).
min_distance: u16Minimum distance the sensor can measure
max_distance: u16Maximum distance the sensor can measure
current_distance: u16Current distance reading
mavtype: MavDistanceSensorType of distance sensor.
id: u8Onboard ID of the sensor
orientation: MavSensorOrientationDirection the sensor faces. downward-facing: ROTATION_PITCH_270, upward-facing: ROTATION_PITCH_90, backward-facing: ROTATION_PITCH_180, forward-facing: ROTATION_NONE, left-facing: ROTATION_YAW_90, right-facing: ROTATION_YAW_270
covariance: u8Measurement variance. Max standard deviation is 6cm. UINT8_MAX if unknown.
horizontal_fov: f32Horizontal Field of View (angle) where the distance measurement is valid and the field of view is known. Otherwise this is set to 0.
vertical_fov: f32Vertical Field of View (angle) where the distance measurement is valid and the field of view is known. Otherwise this is set to 0.
quaternion: [f32; 4]Quaternion of the sensor orientation in vehicle body frame (w, x, y, z order, zero-rotation is 1, 0, 0, 0). Zero-rotation is along the vehicle body x-axis. This field is required if the orientation is set to MAV_SENSOR_ROTATION_CUSTOM. Set it to 0 if invalid.“
signal_quality: u8Signal quality of the sensor. Specific to each sensor type, representing the relation of the signal strength with the target reflectivity, distance, size or aspect, but normalised as a percentage. 0 = unknown/unset signal quality, 1 = invalid signal, 100 = perfect signal.
Implementations