pub struct GIMBAL_MANAGER_SET_PITCHYAW_DATA {
pub flags: GimbalManagerFlags,
pub pitch: f32,
pub yaw: f32,
pub pitch_rate: f32,
pub yaw_rate: f32,
pub target_system: u8,
pub target_component: u8,
pub gimbal_device_id: u8,
}dialect-marsh only.Expand description
Set gimbal manager pitch and yaw angles (high rate message). This message is to be sent to the gimbal manager (e.g. from a ground station) and will be ignored by gimbal devices. Angles and rates can be set to NaN according to use case. Use MAV_CMD_DO_GIMBAL_MANAGER_PITCHYAW for low-rate adjustments that require confirmation.
ID: 287
Fields
flags: GimbalManagerFlagsHigh level gimbal manager flags to use.
pitch: f32Pitch angle (positive: up, negative: down, NaN to be ignored).
yaw: f32Yaw angle (positive: to the right, negative: to the left, NaN to be ignored).
pitch_rate: f32Pitch angular rate (positive: up, negative: down, NaN to be ignored).
yaw_rate: f32Yaw angular rate (positive: to the right, negative: to the left, NaN to be ignored).
target_system: u8System ID
target_component: u8Component ID
gimbal_device_id: u8Component ID of gimbal device to address (or 1-6 for non-MAVLink gimbal), 0 for all gimbal device components. Send command multiple times for more than one gimbal (but not all gimbals).
Implementations