pub struct RAW_IMU_DATA {
pub time_usec: u64,
pub xacc: i16,
pub yacc: i16,
pub zacc: i16,
pub xgyro: i16,
pub ygyro: i16,
pub zgyro: i16,
pub xmag: i16,
pub ymag: i16,
pub zmag: i16,
pub id: u8,
pub temperature: i16,
}dialect-marsh only.Expand description
The RAW IMU readings for a 9DOF sensor, which is identified by the id (default IMU1). This message should always contain the true raw values without any scaling to allow data capture and system debugging.
ID: 27
Fields
time_usec: u64Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
xacc: i16X acceleration (raw)
yacc: i16Y acceleration (raw)
zacc: i16Z acceleration (raw)
xgyro: i16Angular speed around X axis (raw)
ygyro: i16Angular speed around Y axis (raw)
zgyro: i16Angular speed around Z axis (raw)
xmag: i16X Magnetic field (raw)
ymag: i16Y Magnetic field (raw)
zmag: i16Z Magnetic field (raw)
id: u8Id. Ids are numbered from 0 and map to IMUs numbered from 1 (e.g. IMU1 will have a message with id=0)
temperature: i16Temperature, 0: IMU does not provide temperature values. If the IMU is at 0C it must send 1 (0.01C).
Implementations