pub struct SET_ACTUATOR_CONTROL_TARGET_DATA {
pub time_usec: u64,
pub controls: [f32; 8],
pub group_mlx: u8,
pub target_system: u8,
pub target_component: u8,
}dialect-marsh only.Expand description
Set the vehicle attitude and body angular rates.
ID: 139
Fields
time_usec: u64Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
controls: [f32; 8]Actuator controls. Normed to -1..+1 where 0 is neutral position. Throttle for single rotation direction motors is 0..1, negative range for reverse direction. Standard mapping for attitude controls (group 0): (index 0-7): roll, pitch, yaw, throttle, flaps, spoilers, airbrakes, landing gear. Load a pass-through mixer to repurpose them as generic outputs.
group_mlx: u8Actuator group. The “_mlx” indicates this is a multi-instance message and a MAVLink parser should use this field to difference between instances.
target_system: u8System ID
target_component: u8Component ID
Implementations