pub struct STORAGE_INFORMATION_DATA {
pub time_boot_ms: u32,
pub total_capacity: f32,
pub used_capacity: f32,
pub available_capacity: f32,
pub read_speed: f32,
pub write_speed: f32,
pub storage_id: u8,
pub storage_count: u8,
pub status: StorageStatus,
pub mavtype: StorageType,
pub name: CharArray<32>,
pub storage_usage: StorageUsageFlag,
}dialect-marsh only.Expand description
Information about a storage medium. This message is sent in response to a request with MAV_CMD_REQUEST_MESSAGE and whenever the status of the storage changes (STORAGE_STATUS). Use MAV_CMD_REQUEST_MESSAGE.param2 to indicate the index/id of requested storage: 0 for all, 1 for first, 2 for second, etc.
ID: 261
Fields
time_boot_ms: u32Timestamp (time since system boot).
total_capacity: f32Total capacity. If storage is not ready (STORAGE_STATUS_READY) value will be ignored.
used_capacity: f32Used capacity. If storage is not ready (STORAGE_STATUS_READY) value will be ignored.
available_capacity: f32Available storage capacity. If storage is not ready (STORAGE_STATUS_READY) value will be ignored.
read_speed: f32Read speed.
write_speed: f32Write speed.
storage_id: u8Storage ID (1 for first, 2 for second, etc.)
storage_count: u8Number of storage devices
status: StorageStatusStatus of storage
mavtype: StorageTypeType of storage
name: CharArray<32>Textual storage name to be used in UI (microSD 1, Internal Memory, etc.) This is a NULL terminated string. If it is exactly 32 characters long, add a terminating NULL. If this string is empty, the generic type is shown to the user.
storage_usage: StorageUsageFlagFlags indicating whether this instance is preferred storage for photos, videos, etc. Note: Implementations should initially set the flags on the system-default storage id used for saving media (if possible/supported). This setting can then be overridden using MAV_CMD_SET_STORAGE_USAGE. If the media usage flags are not set, a GCS may assume storage ID 1 is the default storage for all media types.
Implementations